==> php83-nextcloud-29.0.7.tgz: share/nextcloud/apps/files_external/l10n/sl.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Odobri dostop",
    "Error configuring OAuth1" : "Napaka nastavljanja OAuth1",
    "Please provide a valid app key and secret." : "Vpisati je treba veljaven ključ programa in kodo PIN.",
    "Error configuring OAuth2" : "Napaka nastavljanja OAuth2",
    "Generate keys" : "Ustvari ključe",
    "Error generating key pair" : "Prišlo je do napake med ustvarjanjem para ključev",
    "(Group)" : "(skupina)",
    "Compatibility with Mac NFD encoding (slow)" : " Usklajenost s šifriranjem Mac NFD (počasno)",
    "Enable encryption" : "Omogoči šifriranje",
    "Enable previews" : "Omogoči predoglede",
    "Enable sharing" : "Omogoči souporabo",
    "Check for changes" : "Preveri za spremembe",
    "Never" : "Nikoli",
    "Once every direct access" : "Enkrat ob neposrednem dostopu",
    "Read only" : "Le za branje",
    "Disconnect" : "Prekini povezavo",
    "Admin defined" : "Skrbnik je določen",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Samodejno preverjanje stanja je onemogočeno zaradi večjega števila nastavljenih shramb. Stanje je mogoče določiti ročno s klikom.",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Ali ste prepričani, da želite odklopiti to mesto zunanje shrambe? Odklopljena shramba ni na voljo v oblaku Nextcloud, mape in datoteke pa ne bodo dostopne in ne usklajevanje. Datoteke zunanje shrambe ostanejo nedotaknjene.",
    "Delete storage?" : "Ali ste prepričani, da želite izbrisati shrambo?",
    "Click to recheck the configuration" : "Kliknite za ponovno preverjanje nastavitev",
    "Saved" : "Shranjeno",
    "Saving …" : "Poteka shranjevanje ...",
    "Save" : "Shrani",
    "Forbidden to manage local mounts" : "Ni ustreznih dovoljenj za urejanje krajevnih priklopnih točk",
    "Storage with ID \"%d\" not found" : "Shrambe z ID »%d« ni mogoče najti.",
    "Invalid backend or authentication mechanism class" : "Neveljaven ozadnji program oziroma razred mehanizma overitve",
    "Invalid mount point" : "Neveljavna priklopna točka",
    "Objectstore forbidden" : "Shranjevanje predmeta je prepovedano",
    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe » %s «",
    "Not permitted to use backend \"%s\"" : "Uporaba ozadnjega programa »%s« ni dovoljena.",
    "Not permitted to use authentication mechanism \"%s\"" : "Uporaba načina overitve » %s « ni dovoljena.",
    "Unsatisfied backend parameters" : "Nezadovoljivi parametri ozadnjega programa",
    "Unsatisfied authentication mechanism parameters" : "Nezadovoljivi parametri mehanizma overitve",
    "Insufficient data: %s" : "Nepopolni podatki: %s",
    "%s" : "%s",
    "Access key" : "Ključ za dostop",
    "Secret key" : "Skrivni ključ",
    "Builtin" : "Vgrajeno",
    "None" : "Brez",
    "OAuth1" : "OAuth1",
    "App key" : "Programski ključ",
    "App secret" : "Skrivni programski ključ",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID odjemalca",
    "Client secret" : "Skrivni ključ odjemalca",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Prijava",
    "Password" : "Geslo",
    "Tenant name" : "Ime uporabnika",
    "Identity endpoint URL" : "Naslov URL končne točke istovetnosti",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domena",
    "Rackspace" : "Rackspace",
    "API key" : "Ključ API",
    "Global credentials" : "Splošna poverila",
    "Log-in credentials, save in database" : "Poverila prijave, shranjeno v podatkovni zbirki",
    "Log-in credentials, save in session" : "Poverila prijave, shranjeno znotraj seje",
    "RSA public key" : "Javni ključ RSA",
    "Public key" : "Javni ključ",
    "RSA private key" : "Zasebni ključ RSA",
    "Private key" : "Zasebni ključ",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Privzeto območje Kerberos je »WORKGROUP«",
    "Kerberos ticket Apache mode" : "Način Apache kartice Kerberos",
    "Kerberos ticket" : "Kartica Kerberos",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Amazon Bucket",
    "Hostname" : "Ime gostitelja",
    "Port" : "Vrata",
    "Region" : "Območje",
    "Storage Class" : "Vrsta shrambe",
    "Enable SSL" : "Omogoči SSL",
    "Enable Path Style" : "Omogoči slog poti",
    "Legacy (v2) authentication" : "Opuščena (v2) overitev",
    "WebDAV" : "WebDAV",
    "URL" : "Naslov URL",
    "Remote subfolder" : "Oddaljena podrejena mapa",
    "Secure https://" : "Varni način https://",
    "FTP" : "FTP",
    "Host" : "Gostitelj",
    "Secure ftps://" : "Varni način ftps://",
    "Local" : "Krajevno",
    "Location" : "Mesto",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Koren",
    "SFTP with secret key login" : "Prijava z uporabo protokola SFTP z geslom",
    "SMB/CIFS" : "SMB / CIFS",
    "Share" : "Souporaba",
    "Show hidden files" : "Pokaži skrite datoteke",
    "Verify ACL access when listing files" : "Overi dostop ACL pri izpisu seznama datotek",
    "Timeout" : "Časovni zamik",
    "SMB/CIFS using OC login" : "SMB / CIFS z uporabo prijave OC",
    "OpenStack Object Storage" : "Shramba predmeta OpenStack",
    "Service name" : "Ime storitve",
    "Request timeout (seconds)" : "Zahtevan časovni zamik (sekunde)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Podpora za cURL prek PHP ni omogočena ali nameščena. Priklapljanje %s zato ni mogoče. Stopite v stik s skrbnikom sistema, da namesti ustrezne pakete.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Podpora za FTP prek PHP ni omogočena ali nameščena. Priklapljanje %s zato ni mogoče. Stopite v stik s skrbnikom sistema, da namesti ustrezne pakete.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "Paket »%1$s« ni nameščen. Priklapljanje %2$s zato ni mogoče. Stopite v stik s skrbnikom sistema, da namesti ustrezne pakete.",
    "External storage" : "Zunanja shramba",
    "External storage support" : "Podpora zunanji dhrambi",
    "Adds basic external storage support" : "Doda osnovno zunanjo podporo shrambe",
    "Enter missing credentials" : "Vpiši manjkajoča poverila",
    "New configuration successfully saved" : "Nove nastavitve so uspešno shranjene",
    "There was an error with this external storage." : "Prišlo je do napake zunanje shrambe.",
    "Open in Files" : "Odpri v mapi",
    "External mount error" : "Notranja napaka priklopa",
    "Storage type" : "Vrsta shrambe",
    "Unknown" : "Neznano",
    "Scope" : "Obseg",
    "Personal" : "Osebno",
    "System" : "Sistem",
    "No external storage configured or you don't have the permission to configure them" : "Ni nastavljene zunanje shrambe oziroma ni ustreznih dovoljenj za uporabo.",
    "Open documentation" : "Odpri dokumentacijo-",
    "Folder name" : "Ime mape",
    "Authentication" : "Overitev",
    "Configuration" : "Nastavitve",
    "Available for" : "Na voljo za",
    "Add storage" : "Dodaj shrambo",
    "Advanced settings" : "Napredne nastavitve",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Splošna poverila je mogoče uporabiti za overitev z več zunanjimi shrambami, ki uporabljajo enaka poverila.",
    "Type to select user or group." : "Vpišite niz za izbor uporabnika ali skupine.",
    "Storage with ID \"%d\" is not user editable" : "Shrambe z ID »%d« ni mogoče uporabniško urediti.",
    "Username" : "Uporabniško ime",
    "Username and password" : "Uporabniško ime in geslo",
    "Global credentials, user entered" : "Uporabniško vpisana splošna poverila",
    "User entered, store in database" : "Uporabnik vpisan, shranjeno v podatkovni zbirki",
    "Check the ACL's of each file or folder inside a directory to filter out items where the user has no read permissions, comes with a performance penalty" : "Preverite ACL vsake datoteke ali mape, da filtrirate vire, za katere uporabnik nima dovoljenja za branje. Opravilo je lahko časovno iz zmogljivostno zahtevno.",
    "Username as share" : "Uporabniško ime za souporabo",
    "This application enables administrators to configure connections to external storage providers, such as FTP servers, S3 or SWIFT object stores, other Nextcloud servers, WebDAV servers, and more. Administrators can choose which types of storage to enable and can mount these storage locations for a user, a group, or the entire system. Users will see a new folder appear in their root Nextcloud directory, which they can access and use like any other Nextcloud folder. External storage also allows users to share files stored in these external locations. In these cases, the credentials for the owner of the file are used when the recipient requests the file from external storage, thereby ensuring that the recipient can access the shared file.\n\nExternal storage can be configured using the GUI or at the command line. This second option provides the advanced user with more flexibility for configuring bulk external storage mounts and setting mount priorities. More information is available in the external storage GUI documentation and the external storage Configuration File documentation." : "Program omogoča skrbnikom nastavljanje zunanjih shramb in ponudnikov, kot so strežniki FTP, shrambe S3 ali SWIFT, drugih strežnikov Nextcloud, strežnikov WebDAV in še mnogo več. Skrbniki lahko določijo, katere vrste pomnilnikov bodo omogočili in jih odprli za uporabnika, skupino ali za celoten sistem. Uporabniki bodo v svojem korenskem imeniku Nextcloud videli novo dodano mapo, do katere lahko dostopajo enako kot do drugih map Nextcloud. Zunanji pomnilnik uporabnikom omogoča tudi skupno rabo datotek, shranjenih na zunanjih naslovih. V teh primerih se poverilnice lastnika datoteke uporabijo, ko prejemnik datoteko zahteva iz zunanjega pomnilnika, to zagotovi, da lahko prejemnik dostopa do vseh datoteke v skupni rabi.\n\nZunanji pomnilnik je mogoče povezati prek spletnega vmesnika ali prek ukazne vrstice. Slednja možnost omogoča zahtevnejšim uporabnikom večjo prilagodljivost paketnega nastavljanja zunanjih nosilcev za shranjevanje in določanje prednosti namestitve in uporabe. Več podrobnosti je zbranih v dokumentaciji spletnega vmesnika za zunanji pomnilnik in dokumentaciji o nastavitvenih datotekah zunanjega pomnilnika.",
    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "Zunanja shramba omogoča uporabo in priklop zunanjih storitev za shranjevanje in povezane naprave kot dodatna skladišča Nextcloud. Dovoliti je mogoče tudi priklapljanje uporabniških zunanjih shramb v skupno okolje.",
    "All users" : "Vsi uporabniki",
    "Allow users to mount external storage" : "Dovoli uporabnikom priklapljanje zunanje shrambe"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> php83-nextcloud-30.0.11.tgz: share/nextcloud/apps/files_external/l10n/sl.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Odobri dostop",
    "Error configuring OAuth1" : "Napaka nastavljanja OAuth1",
    "Please provide a valid app key and secret." : "Vpisati je treba veljaven ključ programa in kodo PIN.",
    "Error configuring OAuth2" : "Napaka nastavljanja OAuth2",
    "Generate keys" : "Ustvari ključe",
    "Error generating key pair" : "Prišlo je do napake med ustvarjanjem para ključev",
    "Forbidden to manage local mounts" : "Ni ustreznih dovoljenj za urejanje krajevnih priklopnih točk",
    "Storage with ID \"%d\" not found" : "Shrambe z ID »%d« ni mogoče najti.",
    "Invalid backend or authentication mechanism class" : "Neveljaven ozadnji program oziroma razred mehanizma overitve",
    "Invalid mount point" : "Neveljavna priklopna točka",
    "Objectstore forbidden" : "Shranjevanje predmeta je prepovedano",
    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe » %s «",
    "Not permitted to use backend \"%s\"" : "Uporaba ozadnjega programa »%s« ni dovoljena.",
    "Not permitted to use authentication mechanism \"%s\"" : "Uporaba načina overitve » %s « ni dovoljena.",
    "Unsatisfied backend parameters" : "Nezadovoljivi parametri ozadnjega programa",
    "Unsatisfied authentication mechanism parameters" : "Nezadovoljivi parametri mehanizma overitve",
    "Insufficient data: %s" : "Nepopolni podatki: %s",
    "%s" : "%s",
    "Access key" : "Ključ za dostop",
    "Secret key" : "Skrivni ključ",
    "Builtin" : "Vgrajeno",
    "None" : "Brez",
    "OAuth1" : "OAuth1",
    "App key" : "Programski ključ",
    "App secret" : "Skrivni programski ključ",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID odjemalca",
    "Client secret" : "Skrivni ključ odjemalca",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Prijava",
    "Password" : "Geslo",
    "Tenant name" : "Ime uporabnika",
    "Identity endpoint URL" : "Naslov URL končne točke istovetnosti",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domena",
    "Rackspace" : "Rackspace",
    "API key" : "Ključ API",
    "Global credentials" : "Splošna poverila",
    "Log-in credentials, save in database" : "Poverila prijave, shranjeno v podatkovni zbirki",
    "Log-in credentials, save in session" : "Poverila prijave, shranjeno znotraj seje",
    "RSA public key" : "Javni ključ RSA",
    "Public key" : "Javni ključ",
    "RSA private key" : "Zasebni ključ RSA",
    "Private key" : "Zasebni ključ",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Privzeto območje Kerberos je »WORKGROUP«",
    "Kerberos ticket Apache mode" : "Način Apache kartice Kerberos",
    "Kerberos ticket" : "Kartica Kerberos",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Amazon Bucket",
    "Hostname" : "Ime gostitelja",
    "Port" : "Vrata",
    "Region" : "Območje",
    "Storage Class" : "Vrsta shrambe",
    "Enable SSL" : "Omogoči SSL",
    "Enable Path Style" : "Omogoči slog poti",
    "Legacy (v2) authentication" : "Opuščena (v2) overitev",
    "WebDAV" : "WebDAV",
    "URL" : "Naslov URL",
    "Remote subfolder" : "Oddaljena podrejena mapa",
    "Secure https://" : "Varni način https://",
    "FTP" : "FTP",
    "Host" : "Gostitelj",
    "Secure ftps://" : "Varni način ftps://",
    "Local" : "Krajevno",
    "Location" : "Mesto",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Koren",
    "SFTP with secret key login" : "Prijava z uporabo protokola SFTP z geslom",
    "SMB/CIFS" : "SMB / CIFS",
    "Share" : "Souporaba",
    "Show hidden files" : "Pokaži skrite datoteke",
    "Verify ACL access when listing files" : "Overi dostop ACL pri izpisu seznama datotek",
    "Timeout" : "Časovni zamik",
    "SMB/CIFS using OC login" : "SMB / CIFS z uporabo prijave OC",
    "OpenStack Object Storage" : "Shramba predmeta OpenStack",
    "Service name" : "Ime storitve",
    "Request timeout (seconds)" : "Zahtevan časovni zamik (sekunde)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Podpora za cURL prek PHP ni omogočena ali nameščena. Priklapljanje %s zato ni mogoče. Stopite v stik s skrbnikom sistema, da namesti ustrezne pakete.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Podpora za FTP prek PHP ni omogočena ali nameščena. Priklapljanje %s zato ni mogoče. Stopite v stik s skrbnikom sistema, da namesti ustrezne pakete.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "Paket »%1$s« ni nameščen. Priklapljanje %2$s zato ni mogoče. Stopite v stik s skrbnikom sistema, da namesti ustrezne pakete.",
    "External storage" : "Zunanja shramba",
    "External storage support" : "Podpora zunanji dhrambi",
    "Adds basic external storage support" : "Doda osnovno zunanjo podporo shrambe",
    "Confirm" : "Potrdi",
    "New configuration successfully saved" : "Nove nastavitve so uspešno shranjene",
    "Enter missing credentials" : "Vpiši manjkajoča poverila",
    "There was an error with this external storage." : "Prišlo je do napake zunanje shrambe.",
    "Open in Files" : "Odpri v mapi",
    "External mount error" : "Notranja napaka priklopa",
    "Storage type" : "Vrsta shrambe",
    "Unknown" : "Neznano",
    "Scope" : "Obseg",
    "Personal" : "Osebno",
    "System" : "Sistem",
    "(Group)" : "(skupina)",
    "Compatibility with Mac NFD encoding (slow)" : " Usklajenost s šifriranjem Mac NFD (počasno)",
    "Enable encryption" : "Omogoči šifriranje",
    "Enable previews" : "Omogoči predoglede",
    "Enable sharing" : "Omogoči souporabo",
    "Check for changes" : "Preveri za spremembe",
    "Never" : "Nikoli",
    "Once every direct access" : "Enkrat ob neposrednem dostopu",
    "Read only" : "Le za branje",
    "Disconnect" : "Prekini povezavo",
    "Admin defined" : "Skrbnik je določen",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Samodejno preverjanje stanja je onemogočeno zaradi večjega števila nastavljenih shramb. Stanje je mogoče določiti ročno s klikom.",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Ali ste prepričani, da želite odklopiti to mesto zunanje shrambe? Odklopljena shramba ni na voljo v oblaku Nextcloud, mape in datoteke pa ne bodo dostopne in ne usklajevanje. Datoteke zunanje shrambe ostanejo nedotaknjene.",
    "Delete storage?" : "Ali ste prepričani, da želite izbrisati shrambo?",
    "Click to recheck the configuration" : "Kliknite za ponovno preverjanje nastavitev",
    "Saved" : "Shranjeno",
    "Saving …" : "Poteka shranjevanje ...",
    "Save" : "Shrani",
    "No external storage configured or you don't have the permission to configure them" : "Ni nastavljene zunanje shrambe oziroma ni ustreznih dovoljenj za uporabo.",
    "Open documentation" : "Odpri dokumentacijo-",
    "Folder name" : "Ime mape",
    "Authentication" : "Overitev",
    "Configuration" : "Nastavitve",
    "Available for" : "Na voljo za",
    "Add storage" : "Dodaj shrambo",
    "Advanced settings" : "Napredne nastavitve",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Splošna poverila je mogoče uporabiti za overitev z več zunanjimi shrambami, ki uporabljajo enaka poverila."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
